==> anwiba-spatial-data-gpsd-1.0.68-sources.jar: net/anwiba/spatial/gps/gpsd/response/Sky.java <==
//// Copyright (c) 2017 by Andreas W. Bartels (bartels@anwiba.de)
package net.anwiba.spatial.gps.gpsd.response;

import com.fasterxml.jackson.annotation.JsonProperty;

public class Sky
    extends Response
{

    private final String _class = "SKY";
    private String tag = null;
    private String device = null;
    private long time = 0L;
    private double xdop = java.lang.Double.NaN;
    private double ydop = java.lang.Double.NaN;
    private double vdop = java.lang.Double.NaN;
    private double tdop = java.lang.Double.NaN;
    private double hdop = java.lang.Double.NaN;
    private double pdop = java.lang.Double.NaN;
    private double gdop = java.lang.Double.NaN;
    private Satellite[] satellites = null;

    @JsonProperty("class")
    public void setClass(final String _class) {
    }

    @JsonProperty("class")
    public String getCLASS() {
        return this._class;
    }

    @JsonProperty("tag")
    public void setTag(final String tag) {
        this.tag = tag;
    }

    @JsonProperty("tag")
    public String getTag() {
        return this.tag;
    }

    @JsonProperty("device")
    public void setDevice(final String device) {
        this.device = device;
    }

    @JsonProperty("device")
    public String getDevice() {
        return this.device;
    }

    @JsonProperty("time")
    public void setTime(final long time) {
        this.time = time;
    }

    @JsonProperty("time")
    public long getTime() {
        return this.time;
    }

    @JsonProperty("xdop")
    public void setXdop(final double xdop) {
        this.xdop = xdop;
    }

    @JsonProperty("xdop")
    public double getXdop() {
        return this.xdop;
    }

    @JsonProperty("ydop")
    public void setYdop(final double ydop) {
        this.ydop = ydop;
    }

    @JsonProperty("ydop")
    public double getYdop() {
        return this.ydop;
    }

    @JsonProperty("vdop")
    public void setVdop(final double vdop) {
        this.vdop = vdop;
    }

    @JsonProperty("vdop")
    public double getVdop() {
        return this.vdop;
    }

    @JsonProperty("tdop")
    public void setTdop(final double tdop) {
        this.tdop = tdop;
    }

    @JsonProperty("tdop")
    public double getTdop() {
        return this.tdop;
    }

    @JsonProperty("hdop")
    public void setHdop(final double hdop) {
        this.hdop = hdop;
    }

    @JsonProperty("hdop")
    public double getHdop() {
        return this.hdop;
    }

    @JsonProperty("pdop")
    public void setPdop(final double pdop) {
        this.pdop = pdop;
    }

    @JsonProperty("pdop")
    public double getPdop() {
        return this.pdop;
    }

    @JsonProperty("gdop")
    public void setGdop(final double gdop) {
        this.gdop = gdop;
    }

    @JsonProperty("gdop")
    public double getGdop() {
        return this.gdop;
    }

    @JsonProperty("satellites")
    public void setSatellites(final Satellite[] satellites) {
        this.satellites = satellites;
    }

    @JsonProperty("satellites")
    public Satellite[] getSatellites() {
        return this.satellites;
    }

}

==> anwiba-spatial-data-gpsd-1.0.185-sources.jar: net/anwiba/spatial/gps/gpsd/response/Sky.java <==
//// Copyright (c) 2017 by Andreas W. Bartels
package net.anwiba.spatial.gps.gpsd.response;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;

public class Sky
    extends Response
{

    private final String _class = "SKY";
    private String tag = null;
    private String device = null;
    private long time = 0L;
    private double xdop = java.lang.Double.NaN;
    private double ydop = java.lang.Double.NaN;
    private double vdop = java.lang.Double.NaN;
    private double tdop = java.lang.Double.NaN;
    private double hdop = java.lang.Double.NaN;
    private double pdop = java.lang.Double.NaN;
    private double gdop = java.lang.Double.NaN;
    private Satellite[] satellites = null;

    @JsonIgnore
    public void setClass(final String _class) {
    }

    @JsonIgnore
    public String getCLASS() {
        return this._class;
    }

    @JsonProperty("tag")
    public void setTag(final String tag) {
        this.tag = tag;
    }

    @JsonProperty("tag")
    public String getTag() {
        return this.tag;
    }

    @JsonProperty("device")
    public void setDevice(final String device) {
        this.device = device;
    }

    @JsonProperty("device")
    public String getDevice() {
        return this.device;
    }

    @JsonProperty("time")
    public void setTime(final long time) {
        this.time = time;
    }

    @JsonProperty("time")
    public long getTime() {
        return this.time;
    }

    @JsonProperty("xdop")
    public void setXdop(final double xdop) {
        this.xdop = xdop;
    }

    @JsonProperty("xdop")
    public double getXdop() {
        return this.xdop;
    }

    @JsonProperty("ydop")
    public void setYdop(final double ydop) {
        this.ydop = ydop;
    }

    @JsonProperty("ydop")
    public double getYdop() {
        return this.ydop;
    }

    @JsonProperty("vdop")
    public void setVdop(final double vdop) {
        this.vdop = vdop;
    }

    @JsonProperty("vdop")
    public double getVdop() {
        return this.vdop;
    }

    @JsonProperty("tdop")
    public void setTdop(final double tdop) {
        this.tdop = tdop;
    }

    @JsonProperty("tdop")
    public double getTdop() {
        return this.tdop;
    }

    @JsonProperty("hdop")
    public void setHdop(final double hdop) {
        this.hdop = hdop;
    }

    @JsonProperty("hdop")
    public double getHdop() {
        return this.hdop;
    }

    @JsonProperty("pdop")
    public void setPdop(final double pdop) {
        this.pdop = pdop;
    }

    @JsonProperty("pdop")
    public double getPdop() {
        return this.pdop;
    }

    @JsonProperty("gdop")
    public void setGdop(final double gdop) {
        this.gdop = gdop;
    }

    @JsonProperty("gdop")
    public double getGdop() {
        return this.gdop;
    }

    @JsonProperty("satellites")
    public void setSatellites(final Satellite[] satellites) {
        this.satellites = satellites;
    }

    @JsonProperty("satellites")
    public Satellite[] getSatellites() {
        return this.satellites;
    }

}
